import React from 'react';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _inheritsLoose(subClass, superClass) {
  subClass.prototype = Object.create(superClass.prototype);
  subClass.prototype.constructor = subClass;
  subClass.__proto__ = superClass;
}

var PointDefinitions = function PointDefinitions(_ref) {
  var sets = _ref.sets;
  var pointDefinitions = sets.map(function (_ref2) {
    var size = _ref2.size,
        color = _ref2.color,
        opacity = _ref2.opacity,
        id = _ref2.id;
    var props = {
      opacity: opacity,
      id: id,
      cx: 0,
      cy: 0,
      r: size,
      fill: color
    };
    return /*#__PURE__*/React.createElement("circle", _extends({}, props, {
      key: id
    }));
  });
  return /*#__PURE__*/React.createElement("defs", null, pointDefinitions);
};

var createPointInstances = function createPointInstances(points, transforms) {
  return points.x.map(function (x, i) {
    return /*#__PURE__*/React.createElement("use", {
      x: transforms.tx(x),
      y: transforms.ty(points.y[i]),
      href: "#" + points.id,
      key: points.id + i
    });
  });
};

var Points = function Points(_ref3) {
  var sets = _ref3.sets,
      transforms = _ref3.transforms;
  return sets.reduce(function (points, pointSet) {
    return [].concat(points, [createPointInstances(pointSet, transforms)]);
  }, []);
};

var LineSet = function LineSet(_ref4) {
  var size = _ref4.size,
      color = _ref4.color,
      opacity = _ref4.opacity,
      x0 = _ref4.x0,
      x1 = _ref4.x1,
      y0 = _ref4.y0,
      y1 = _ref4.y1,
      transforms = _ref4.transforms,
      id = _ref4.id;
  var d = x0.reduce(function (currentD, rawX0, i) {
    var _ref5 = [transforms.tx(rawX0), transforms.tx(x1[i]), transforms.ty(y0[i]), transforms.ty(y1[i])],
        currentX0 = _ref5[0],
        currentX1 = _ref5[1],
        currentY0 = _ref5[2],
        currentY1 = _ref5[3];
    return currentD + " M " + currentX0 + "," + currentY0 + " L " + currentX1 + "," + currentY1 + " ";
  }, '');
  return /*#__PURE__*/React.createElement("path", _extends({
    d: d,
    stroke: color,
    strokeWidth: size
  }, {
    opacity: opacity,
    id: id
  }));
};

var Lines = function Lines(_ref6) {
  var sets = _ref6.sets,
      transforms = _ref6.transforms;
  return sets.map(function (lineSet) {
    return /*#__PURE__*/React.createElement(LineSet, _extends({}, lineSet, {
      transforms: transforms
    }, {
      key: lineSet.id
    }));
  });
};

var Polygon = function Polygon(_ref7) {
  var x = _ref7.x,
      y = _ref7.y,
      fillColor = _ref7.fillColor,
      fillOpacity = _ref7.fillOpacity,
      borderColor = _ref7.borderColor,
      borderOpacity = _ref7.borderOpacity,
      borderSize = _ref7.borderSize,
      transforms = _ref7.transforms,
      id = _ref7.id;
  var pointString = x.reduce(function (pointString, rawX, i) {
    var currentX = transforms.tx(rawX);
    var currentY = transforms.ty(y[i]);
    return "" + pointString + currentX + "," + currentY + " ";
  }, '');
  var props = {
    points: pointString,
    fill: fillColor,
    stroke: borderColor,
    strokeWidth: borderSize,
    strokeOpacity: borderOpacity,
    id: id,
    fillOpacity: fillOpacity
  };
  return /*#__PURE__*/React.createElement("polygon", props);
};

var Polygons = function Polygons(_ref8) {
  var sets = _ref8.sets,
      transforms = _ref8.transforms;
  return sets.map(function (polygon) {
    return /*#__PURE__*/React.createElement(Polygon, _extends({}, polygon, {
      transforms: transforms
    }, {
      key: polygon.id
    }));
  });
};

var Ellipse = function Ellipse(_ref9) {
  var cx = _ref9.cx,
      cy = _ref9.cy,
      rx = _ref9.rx,
      ry = _ref9.ry,
      theta = _ref9.theta,
      fillColor = _ref9.fillColor,
      fillOpacity = _ref9.fillOpacity,
      borderColor = _ref9.borderColor,
      borderOpacity = _ref9.borderOpacity,
      borderSize = _ref9.borderSize,
      transforms = _ref9.transforms,
      id = _ref9.id;
  var newCx = transforms.tx(cx);
  var newCy = transforms.ty(cy);
  var props = {
    cx: newCx,
    cy: newCy,
    rx: rx,
    ry: ry,
    fill: fillColor,
    stroke: borderColor,
    strokeWidth: borderSize,
    strokeOpacity: borderOpacity,
    id: id,
    fillOpacity: fillOpacity,
    transform: "rotate(" + theta + ", " + newCx + ", " + newCy + ")"
  };
  return /*#__PURE__*/React.createElement("ellipse", props);
};

var Ellipses = function Ellipses(_ref10) {
  var sets = _ref10.sets,
      transforms = _ref10.transforms;
  return sets.map(function (ellipse) {
    return /*#__PURE__*/React.createElement(Ellipse, _extends({}, ellipse, {
      transforms: transforms
    }, {
      key: ellipse.id
    }));
  });
};

var svgProps = {
  version: '1.1',
  baseProfile: 'full',
  xmlns: 'http://www.w3.org/2000/svg',
  preserveAspectRatio: 'xMidYMid slice',
  width: '100%',
  height: '100%'
};

var Paper = function Paper(_ref) {
  var color = _ref.color,
      opacity = _ref.opacity;
  return /*#__PURE__*/React.createElement("rect", {
    width: "100%",
    height: "100%",
    fill: color,
    opacity: opacity
  });
};

var filterSet = function filterSet(data, type) {
  return data.filter(function (dataSet) {
    return dataSet.type === type;
  });
};

var BareMinimum2d = /*#__PURE__*/function (_React$PureComponent) {
  _inheritsLoose(BareMinimum2d, _React$PureComponent);

  function BareMinimum2d() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$PureComponent.call.apply(_React$PureComponent, [this].concat(args)) || this;
    _this.xRange = null;
    _this.yRange = null;

    _this.transformX = function (x) {
      return x + _this.xRange / 2;
    };

    _this.transformY = function (y) {
      return _this.yRange / 2 - y;
    };

    return _this;
  }

  var _proto = BareMinimum2d.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        container = _this$props.container,
        data = _this$props.data;
    this.xRange = container.xRange;
    this.yRange = container.yRange;
    var pointSets = filterSet(data, 'points');
    var lineSets = filterSet(data, 'lines');
    var polygonSets = filterSet(data, 'polygon');
    var ellipseSets = filterSet(data, 'ellipse');
    var transforms = {
      tx: this.transformX,
      ty: this.transformY
    };
    var viewBox = "0 0 " + container.xRange + " " + container.yRange;
    var color = container.color,
        opacity = container.opacity;
    return /*#__PURE__*/React.createElement("svg", _extends({}, svgProps, {
      viewBox: viewBox
    }), /*#__PURE__*/React.createElement(Paper, {
      color: color,
      opacity: opacity
    }), /*#__PURE__*/React.createElement(PointDefinitions, {
      sets: pointSets
    }), /*#__PURE__*/React.createElement(Polygons, _extends({
      sets: polygonSets
    }, {
      transforms: transforms
    })), /*#__PURE__*/React.createElement(Lines, _extends({
      sets: lineSets
    }, {
      transforms: transforms
    })), /*#__PURE__*/React.createElement(Ellipses, _extends({
      sets: ellipseSets
    }, {
      transforms: transforms
    })), /*#__PURE__*/React.createElement(Points, _extends({
      sets: pointSets
    }, {
      transforms: transforms
    })));
  };

  return BareMinimum2d;
}(React.PureComponent);

export { BareMinimum2d };
//# sourceMappingURL=index.modern.js.map
